@@ -1,7 +1,7 @@
 from django.core.exceptions import ValidationError
 from django_filters.rest_framework import DjangoFilterBackend
 from rest_framework import viewsets, mixins, permissions, status, views, authentication
-from rest_framework.decorators import detail_route, list_route
+from rest_framework.decorators import action
 from rest_framework.response import Response
 from apollo.models import Form, FormFieldTemplate, FormField, FormSubmission, Layout
 from .serializers import *
@@ -42,16 +42,16 @@ class FormViewSet(viewsets.ModelViewSet):
     serializer_class = FormSerializer
     permission_classes = (permissions.DjangoModelPermissionsOrAnonReadOnly,)
     filter_backends = (DjangoFilterBackend,)
-    filter_fields = ('name',)
+    filterset_fields = ('name',)
 
-    @detail_route(['POST'])
+    @action(detail=True, methods=['post'])
     def clone(self, request, pk=None):
         form = self.get_object()
         clone = form.clone()
 
         return Response(FormSerializer(clone).data, status=status.HTTP_201_CREATED)
 
-    @list_route(['POST'], url_path='import')
+    @action(detail=False, methods=['post'], url_path='import')
     def import_form(self, request, pk=None):
         imported = Form.create_from_json(request.data)
         return Response(FormSerializer(imported).data, status=status.HTTP_201_CREATED)
@@ -160,7 +160,7 @@ class FormSubmissionViewSet(viewsets.ModelViewSet):
     permission_classes = (FormSubmissionsPermission,)
 
     filter_backends = (DjangoFilterBackend,)
-    filter_fields = ('form_id',)
+    filterset_fields = ('form_id',)
 
     def create(self, request, *args, **kwargs):
         try:
