@@ -1,4 +1,4 @@
-from django.conf.urls import url, include
+from django.urls import path, include
 from rest_framework import routers
 from rest_framework.authtoken import views as token_views
 from rest_framework_swagger.views import get_swagger_view
@@ -18,7 +18,7 @@ urlpatterns = router.urls
 schema_view = get_swagger_view(title='Apollo API')
 
 urlpatterns += (
-    url(r'field-options/', api_views.FormFieldOptionsAPIView.as_view()),
-    url(r'auth-token', token_views.obtain_auth_token),
-    url(r'docs/', schema_view)
+    path('field-options/', api_views.FormFieldOptionsAPIView.as_view()),
+    path('auth-token', token_views.obtain_auth_token),
+    path('docs/', schema_view)
 )
\ No newline at end of file
