@@ -1,7 +1,8 @@
 from __future__ import unicode_literals
 
 from django.db import models
-from django.contrib.postgres.fields import ArrayField, JSONField
+from django.contrib.postgres.fields import ArrayField
+from django.db.models import JSONField
 from django.core.exceptions import ValidationError
 from django.conf import settings
 from apollo import forms, signals
@@ -31,7 +32,7 @@ class Layout(models.Model):
 
 class LayoutField(models.Model):
     """ the positioning of a field in the forms' layout """
-    layout = models.ForeignKey(Layout, related_name='blocks')
+    layout = models.ForeignKey(Layout, related_name='blocks', on_delete=models.CASCADE)
 
     # width and height are in pct relative
     desktop_width = models.DecimalField(max_digits=6, decimal_places=3)
@@ -50,6 +51,8 @@ class LayoutField(models.Model):
 
 #####-----< Forms >----#####
 class Form(models.Model):
+    layout = models.ForeignKey(Layout, related_name='forms', null=True, blank=True, default=None, on_delete=models.CASCADE)
+
     name = models.CharField(max_length=200, unique=True)
 
     redirect_url = models.CharField(max_length=150, null=True, blank=True, default=None)
@@ -64,8 +67,6 @@ class Form(models.Model):
     # if true, forms will use recaptcha v3 for verification
     include_recaptcha = models.BooleanField(default=False)
 
-    layout = models.ForeignKey(Layout, related_name='forms', null=True, blank=True, default=None)
-
     @classmethod
     def create_from_json(cls, form_data):
         """ instantiates a form instance and its associated fields from its serialized variation.
@@ -79,7 +80,7 @@ class Form(models.Model):
         existing_form_field_template_names = set(FormFieldTemplate.objects.values_list('name', flat=True))
 
         form_serializer = serializers.FormSerializer(data=form_data)
-        logger.debug(f'form data is {form_data}')
+        logger.debug('form data is {}'.format(form_data))
         if form_serializer.is_valid():
             # we need to create field templates for all fields don't currently exist for the form
             for form_field in form_serializer.validated_data['fields']:
@@ -91,7 +92,7 @@ class Form(models.Model):
             # then save the form and all fields to the DB
             return form_serializer.save()
         else:
-            raise ValidationError(f'form serializer failed to deserialize with error(s) {form_serializer.errors}')
+            raise ValidationError('form serializer failed to deserialize with error(s) {}'.format(form_serializer.errors))
 
     def clone(self):
         """ clone this form to a new form. In addition to the basic fields of this model, this has the effect of copying:
@@ -240,8 +241,8 @@ class FormField(models.Model):
     because while the template governs the common configuration of a field, there are certain properties which
     might need overriding on a per-form basis (designated by a leyou ading _)
     """
-    form = models.ForeignKey(Form, related_name='fields')
-    template = models.ForeignKey(FormFieldTemplate, related_name='instances')
+    form = models.ForeignKey(Form, related_name='fields', on_delete=models.CASCADE)
+    template = models.ForeignKey(FormFieldTemplate, related_name='instances', on_delete=models.CASCADE)
     layout = models.ForeignKey(LayoutField, null=True, blank=True, default=None, on_delete=models.SET_NULL)
 
     label = models.CharField(max_length=100, null=True, blank=True, default=None)
@@ -287,7 +288,7 @@ class FormField(models.Model):
 
 #####-----< Submissions >----#####
 class FormSubmission(models.Model):
-    form = models.ForeignKey(Form, related_name='submissions')
+    form = models.ForeignKey(Form, related_name='submissions', on_delete=models.CASCADE)
 
     raw_data = JSONField()
     cleaned_data = JSONField(blank=True, null=True, default=None)
@@ -369,7 +370,7 @@ class FormSubmission(models.Model):
 #####-----< API >----#####
 class APIUser(models.Model):
     """ an APIUser is the only type we allow to authenticate with Token auth (as opposed to session auth) """
-    auth_user = models.ForeignKey(settings.AUTH_USER_MODEL, related_name='apis')
+    auth_user = models.ForeignKey(settings.AUTH_USER_MODEL, related_name='apis', on_delete=models.CASCADE)
     service_name = models.CharField(max_length=200)
 
     def __str__(self):
@@ -386,7 +387,7 @@ class ExternalWebhook(models.Model):
         (EVENT_SUBMISSION_CREATED, EVENT_SUBMISSION_CREATED),
     )
 
-    form = models.ForeignKey(Form, related_name='external_hooks')
+    form = models.ForeignKey(Form, related_name='external_hooks', on_delete=models.CASCADE)
 
     url = models.CharField(max_length=255)
     for_event = models.CharField(max_length=100, choices=ALLOWED_EVENTS)
